@@ -150,6 +150,11 @@
 //!
 //! To customize the version format, use the [`Parser::version_format`] method.
 //!
+//! # Optional features
+//!
+//! * **`serde`** — Implements [`serde::Serialize`] trait for parse-changelog types.
+//!
+//! [`serde::Serialize`]: https://docs.rs/serde/1/serde/trait.Serialize.html
 //! [keepachangelog]: https://keepachangelog.com/en/1.0.0
 //! [semver]: https://semver.org/spec/v2.0.0.html
 
@@ -235,12 +240,14 @@ pub fn parse(text: &str) -> Result<Changelog<'_>> {
 /// See crate level documentation for changelog and version format supported
 /// by default.
 pub fn parse_iter(text: &str) -> ParseIter<'_, 'static> {
-    ParseIter::new(text, &DEFAULT_VERSION_FORMAT, &DEFAULT_PREFIX_FORMAT)
+    ParseIter::new(text, None, None)
 }
 
 /// A release note for a version.
 #[allow(single_use_lifetimes)] // https://github.com/rust-lang/rust/issues/69952
 #[derive(Debug, Clone, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde_crate::Serialize))]
+#[cfg_attr(feature = "serde", serde(crate = "serde_crate"))]
 #[non_exhaustive]
 pub struct Release<'a> {
     /// The version of this release.
@@ -382,14 +389,6 @@ impl Parser {
         Ok(self)
     }
 
-    fn get_version_format(&self) -> &Regex {
-        self.version.as_ref().unwrap_or(&DEFAULT_VERSION_FORMAT)
-    }
-
-    fn get_prefix_format(&self) -> &Regex {
-        self.prefix.as_ref().unwrap_or(&DEFAULT_PREFIX_FORMAT)
-    }
-
     /// Parses release notes from the given `text`.
     ///
     /// See crate level documentation for changelog and version format supported
@@ -429,7 +428,7 @@ impl Parser {
     ///
     /// [`parse`]: Self::parse
     pub fn parse_iter<'a, 'b>(&'b self, text: &'a str) -> ParseIter<'a, 'b> {
-        ParseIter::new(text, self.get_version_format(), self.get_prefix_format())
+        ParseIter::new(text, self.version.as_ref(), self.prefix.as_ref())
     }
 }
 
@@ -461,11 +460,15 @@ const OPEN: &[u8] = b"<!--";
 const CLOSE: &[u8] = b"-->";
 
 impl<'a, 'b> ParseIter<'a, 'b> {
-    fn new(text: &'a str, version_format: &'b Regex, prefix_format: &'b Regex) -> Self {
+    fn new(
+        text: &'a str,
+        version_format: Option<&'b Regex>,
+        prefix_format: Option<&'b Regex>,
+    ) -> Self {
         Self {
             text,
-            version_format,
-            prefix_format,
+            version_format: version_format.unwrap_or(&DEFAULT_VERSION_FORMAT),
+            prefix_format: prefix_format.unwrap_or(&DEFAULT_PREFIX_FORMAT),
             line_start: 0,
             lines: memchr::memchr_iter(LN, text.as_bytes()).peekable(),
             cur_release: Release::new(),
@@ -639,9 +642,6 @@ fn heading<'a>(
     line_end: usize,
     lines: &mut Peekable<impl Iterator<Item = usize>>,
 ) -> Option<Heading<'a>> {
-    static ALL_EQUAL_SIGNS: Lazy<Regex> = Lazy::new(|| Regex::new("^=+$").unwrap());
-    static ALL_DASHES: Lazy<Regex> = Lazy::new(|| Regex::new("^-+$").unwrap());
-
     let line = trim(line);
     if line.starts_with('#') {
         let mut level = 0;
@@ -655,9 +655,11 @@ fn heading<'a>(
         }
     } else if let Some(&next) = lines.peek() {
         let next = trim(&text[line_end + 1..next]);
-        if ALL_EQUAL_SIGNS.is_match(next) {
+        if next.is_empty() {
+            None
+        } else if next.as_bytes().iter().all(|&b| b == b'=') {
             Some(Heading { text: line, level: 1, style: HeadingStyle::Setext })
-        } else if ALL_DASHES.is_match(next) {
+        } else if next.as_bytes().iter().all(|&b| b == b'-') {
             Some(Heading { text: line, level: 2, style: HeadingStyle::Setext })
         } else {
             None
